==> nmrium-0.50.1.tgz: package/lib/data/matrixGeneration.js <==
import lodashSet from 'lodash/set';
import filterXY from 'ml-signal-processing/FilterXYSchema.json';
export function normalCase(str) {
    const result = str.replaceAll(/(?<upper>[A-Z])/g, ' $<upper>').trim();
    return result.charAt(0).toUpperCase() + result.slice(1);
}
function isLeave(fieldOptions) {
    if (['number', 'boolean', 'string'].includes(fieldOptions.type)) {
        return true;
    }
    return false;
}
function flattenFields(filterName, data, properties, keysPath, parentObject, level) {
    for (const fieldKey in data) {
        let _keysPath = [];
        const _keysPathObject = parentObject || null;
        let _level = level || 0;
        if (keysPath) {
            _keysPath = _keysPath.concat(keysPath);
        }
        _keysPath.push(fieldKey);
        if (data[fieldKey]?.properties) {
            properties[_keysPath.join('.')] = {
                type: 'label',
                description: data[fieldKey].description,
                level: _level,
                name: normalCase(fieldKey),
                key: fieldKey,
            };
            flattenFields(filterName, data[fieldKey]?.properties, properties, _keysPath, null, ++_level);
        }
        else if (data[fieldKey]?.items) {
            flattenFields(filterName, data[fieldKey]?.items?.properties, properties, _keysPath, {
                type: 'list',
                properties: {},
                default: [],
                description: data[fieldKey]?.description,
                name: normalCase(fieldKey),
                key: fieldKey,
                level: 0,
            }, ++_level);
        }
        if (isLeave(data[fieldKey])) {
            const fieldData = {
                ...data[fieldKey],
                level: _level,
                name: normalCase(fieldKey),
                key: fieldKey,
            };
            if (_keysPathObject?.type === 'list') {
                const previousKey = _keysPath.slice(0, -1).join('.');
                properties[previousKey] = _keysPathObject;
                properties[previousKey].properties[_keysPath.join('.')] =
                    fieldData;
            }
            else if (data[fieldKey].enum) {
                const { enum: choices, ...restProps } = fieldData;
                properties[_keysPath.join('.')] = {
                    choices,
                    ...restProps,
                    type: 'select',
                };
            }
            else {
                properties[_keysPath.join('.')] = fieldData;
            }
        }
    }
    return properties;
}
const IGNORED_FILERS = new Set([
    'equallySpaced',
    'filterX',
    'fromTo',
]);
export function getMatrixFilters() {
    const result = [];
    for (const filter of filterXY.anyOf) {
        const filterData = filter.properties;
        const filterProperties = filterData?.options;
        const name = filterData.name.enum[0];
        if (!IGNORED_FILERS.has(name)) {
            const properties = flattenFields(name, filterProperties?.properties, {}, [], null, 0);
            result.push({
                name,
                properties,
                options: generateFilterOptions(properties),
            });
        }
    }
    return result;
}
function generateFilterOptions(properties) {
    const options = {};
    for (const key in properties) {
        const field = properties[key];
        switch (field.type) {
            case 'list':
                lodashSet(options, key, []);
                break;
            case 'select':
                lodashSet(options, key, field.default
                    ? field.default.replaceAll(/'|"/g, '')
                    : field.choices[0]);
                break;
            case 'string':
                lodashSet(options, key, undefined);
                break;
            case 'number': {
                lodashSet(options, key, typeof field.default === 'number' ? field.default : undefined);
                break;
            }
            case 'boolean': {
                lodashSet(options, key, typeof field.default === 'boolean' ? field.default : false);
                break;
            }
            default:
                break;
        }
    }
    return options;
}

==> nmrium-0.53.0.tgz: package/lib/data/matrixGeneration.js <==
import lodashSet from 'lodash/set';
import filterXY from 'ml-signal-processing/FilterXYSchema.json';
export function normalCase(str) {
    const result = str.replaceAll(/(?<upper>[A-Z])/g, ' $<upper>').trim();
    return result.charAt(0).toUpperCase() + result.slice(1);
}
function isLeave(fieldOptions) {
    if (['number', 'boolean', 'string'].includes(fieldOptions.type)) {
        return true;
    }
    return false;
}
function flattenFields(filterName, data, properties, keysPath, parentObject, level) {
    for (const fieldKey in data) {
        let _keysPath = [];
        const _keysPathObject = parentObject || null;
        let _level = level || 0;
        if (keysPath) {
            _keysPath = _keysPath.concat(keysPath);
        }
        _keysPath.push(fieldKey);
        if (data[fieldKey]?.properties) {
            properties[_keysPath.join('.')] = {
                type: 'label',
                description: data[fieldKey].description,
                level: _level,
                name: normalCase(fieldKey),
                key: fieldKey,
            };
            flattenFields(filterName, data[fieldKey]?.properties, properties, _keysPath, null, ++_level);
        }
        else if (data[fieldKey]?.items) {
            flattenFields(filterName, data[fieldKey]?.items?.properties, properties, _keysPath, {
                type: 'list',
                properties: {},
                default: [],
                description: data[fieldKey]?.description,
                name: normalCase(fieldKey),
                key: fieldKey,
                level: 0,
            }, ++_level);
        }
        if (isLeave(data[fieldKey])) {
            const fieldData = {
                ...data[fieldKey],
                level: _level,
                name: normalCase(fieldKey),
                key: fieldKey,
            };
            if (_keysPathObject?.type === 'list') {
                const previousKey = _keysPath.slice(0, -1).join('.');
                properties[previousKey] = _keysPathObject;
                properties[previousKey].properties[_keysPath.join('.')] =
                    fieldData;
            }
            else if (data[fieldKey].enum) {
                const { enum: choices, ...restProps } = fieldData;
                properties[_keysPath.join('.')] = {
                    choices,
                    ...restProps,
                    type: 'select',
                };
            }
            else {
                properties[_keysPath.join('.')] = fieldData;
            }
        }
    }
    return properties;
}
const IGNORED_FILERS = new Set([
    'equallySpaced',
    'filterX',
    'fromTo',
]);
export function getMatrixFilters() {
    const result = [];
    for (const filter of filterXY.anyOf) {
        const filterData = filter.properties;
        const filterProperties = filterData?.options;
        const name = filterData.name.const;
        if (!IGNORED_FILERS.has(name)) {
            const properties = flattenFields(name, filterProperties?.properties, {}, [], null, 0);
            result.push({
                name,
                properties,
                options: generateFilterOptions(properties),
            });
        }
    }
    return result;
}
function generateFilterOptions(properties) {
    const options = {};
    for (const key in properties) {
        const field = properties[key];
        switch (field.type) {
            case 'list':
                lodashSet(options, key, []);
                break;
            case 'select':
                lodashSet(options, key, field.default
                    ? field.default.replaceAll(/'|"/g, '')
                    : field.choices[0]);
                break;
            case 'string':
                lodashSet(options, key, undefined);
                break;
            case 'number': {
                lodashSet(options, key, typeof field.default === 'number' ? field.default : undefined);
                break;
            }
            case 'boolean': {
                lodashSet(options, key, typeof field.default === 'boolean' ? field.default : false);
                break;
            }
            default:
                break;
        }
    }
    return options;
}
